//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armdatabox_test

import (
	"context"
	"log"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/databox/armdatabox"
)

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/databox/resource-manager/Microsoft.DataBox/stable/2021-12-01/examples/ValidateAddressPost.json
func ExampleServiceClient_ValidateAddress() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armdatabox.NewServiceClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.ValidateAddress(ctx,
		"<location>",
		armdatabox.ValidateAddress{
			ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateAddress),
			DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
			ShippingAddress: &armdatabox.ShippingAddress{
				AddressType:     to.Ptr(armdatabox.AddressTypeCommercial),
				City:            to.Ptr("<city>"),
				CompanyName:     to.Ptr("<company-name>"),
				Country:         to.Ptr("<country>"),
				PostalCode:      to.Ptr("<postal-code>"),
				StateOrProvince: to.Ptr("<state-or-province>"),
				StreetAddress1:  to.Ptr("<street-address1>"),
				StreetAddress2:  to.Ptr("<street-address2>"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/databox/resource-manager/Microsoft.DataBox/stable/2021-12-01/examples/ValidateInputsByResourceGroup.json
func ExampleServiceClient_ValidateInputsByResourceGroup() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armdatabox.NewServiceClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.ValidateInputsByResourceGroup(ctx,
		"<resource-group-name>",
		"<location>",
		&armdatabox.CreateJobValidations{
			IndividualRequestDetails: []armdatabox.ValidationInputRequestClassification{
				&armdatabox.DataTransferDetailsValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateDataTransferDetails),
					DataImportDetails: []*armdatabox.DataImportDetails{
						{
							AccountDetails: &armdatabox.StorageAccountDetails{
								DataAccountType:  to.Ptr(armdatabox.DataAccountTypeStorageAccount),
								StorageAccountID: to.Ptr("<storage-account-id>"),
							},
						}},
					DeviceType:   to.Ptr(armdatabox.SKUNameDataBox),
					TransferType: to.Ptr(armdatabox.TransferTypeImportToAzure),
				},
				&armdatabox.ValidateAddress{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateAddress),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
					ShippingAddress: &armdatabox.ShippingAddress{
						AddressType:     to.Ptr(armdatabox.AddressTypeCommercial),
						City:            to.Ptr("<city>"),
						CompanyName:     to.Ptr("<company-name>"),
						Country:         to.Ptr("<country>"),
						PostalCode:      to.Ptr("<postal-code>"),
						StateOrProvince: to.Ptr("<state-or-province>"),
						StreetAddress1:  to.Ptr("<street-address1>"),
						StreetAddress2:  to.Ptr("<street-address2>"),
					},
					TransportPreferences: &armdatabox.TransportPreferences{
						PreferredShipmentType: to.Ptr(armdatabox.TransportShipmentTypesMicrosoftManaged),
					},
				},
				&armdatabox.SubscriptionIsAllowedToCreateJobValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateSubscriptionIsAllowedToCreateJob),
				},
				&armdatabox.SKUAvailabilityValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateSKUAvailability),
					Country:        to.Ptr("<country>"),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
					Location:       to.Ptr("<location>"),
					TransferType:   to.Ptr(armdatabox.TransferTypeImportToAzure),
				},
				&armdatabox.CreateOrderLimitForSubscriptionValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateCreateOrderLimit),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
				},
				&armdatabox.PreferencesValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidatePreferences),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
					Preference: &armdatabox.Preferences{
						TransportPreferences: &armdatabox.TransportPreferences{
							PreferredShipmentType: to.Ptr(armdatabox.TransportShipmentTypesMicrosoftManaged),
						},
					},
				}},
			ValidationCategory: to.Ptr("<validation-category>"),
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/databox/resource-manager/Microsoft.DataBox/stable/2021-12-01/examples/ValidateInputs.json
func ExampleServiceClient_ValidateInputs() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armdatabox.NewServiceClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.ValidateInputs(ctx,
		"<location>",
		&armdatabox.CreateJobValidations{
			IndividualRequestDetails: []armdatabox.ValidationInputRequestClassification{
				&armdatabox.DataTransferDetailsValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateDataTransferDetails),
					DataImportDetails: []*armdatabox.DataImportDetails{
						{
							AccountDetails: &armdatabox.StorageAccountDetails{
								DataAccountType:  to.Ptr(armdatabox.DataAccountTypeStorageAccount),
								StorageAccountID: to.Ptr("<storage-account-id>"),
							},
						}},
					DeviceType:   to.Ptr(armdatabox.SKUNameDataBox),
					TransferType: to.Ptr(armdatabox.TransferTypeImportToAzure),
				},
				&armdatabox.ValidateAddress{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateAddress),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
					ShippingAddress: &armdatabox.ShippingAddress{
						AddressType:     to.Ptr(armdatabox.AddressTypeCommercial),
						City:            to.Ptr("<city>"),
						CompanyName:     to.Ptr("<company-name>"),
						Country:         to.Ptr("<country>"),
						PostalCode:      to.Ptr("<postal-code>"),
						StateOrProvince: to.Ptr("<state-or-province>"),
						StreetAddress1:  to.Ptr("<street-address1>"),
						StreetAddress2:  to.Ptr("<street-address2>"),
					},
					TransportPreferences: &armdatabox.TransportPreferences{
						PreferredShipmentType: to.Ptr(armdatabox.TransportShipmentTypesMicrosoftManaged),
					},
				},
				&armdatabox.SubscriptionIsAllowedToCreateJobValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateSubscriptionIsAllowedToCreateJob),
				},
				&armdatabox.SKUAvailabilityValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateSKUAvailability),
					Country:        to.Ptr("<country>"),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
					Location:       to.Ptr("<location>"),
					TransferType:   to.Ptr(armdatabox.TransferTypeImportToAzure),
				},
				&armdatabox.CreateOrderLimitForSubscriptionValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidateCreateOrderLimit),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
				},
				&armdatabox.PreferencesValidationRequest{
					ValidationType: to.Ptr(armdatabox.ValidationInputDiscriminatorValidatePreferences),
					DeviceType:     to.Ptr(armdatabox.SKUNameDataBox),
					Preference: &armdatabox.Preferences{
						TransportPreferences: &armdatabox.TransportPreferences{
							PreferredShipmentType: to.Ptr(armdatabox.TransportShipmentTypesMicrosoftManaged),
						},
					},
				}},
			ValidationCategory: to.Ptr("<validation-category>"),
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/databox/resource-manager/Microsoft.DataBox/stable/2021-12-01/examples/RegionConfiguration.json
func ExampleServiceClient_RegionConfiguration() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armdatabox.NewServiceClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.RegionConfiguration(ctx,
		"<location>",
		armdatabox.RegionConfigurationRequest{
			ScheduleAvailabilityRequest: &armdatabox.ScheduleAvailabilityRequest{
				SKUName:         to.Ptr(armdatabox.SKUNameDataBox),
				StorageLocation: to.Ptr("<storage-location>"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/databox/resource-manager/Microsoft.DataBox/stable/2021-12-01/examples/RegionConfigurationByResourceGroup.json
func ExampleServiceClient_RegionConfigurationByResourceGroup() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armdatabox.NewServiceClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.RegionConfigurationByResourceGroup(ctx,
		"<resource-group-name>",
		"<location>",
		armdatabox.RegionConfigurationRequest{
			ScheduleAvailabilityRequest: &armdatabox.ScheduleAvailabilityRequest{
				SKUName:         to.Ptr(armdatabox.SKUNameDataBox),
				StorageLocation: to.Ptr("<storage-location>"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}
