//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armmonitor_test

import (
	"context"
	"log"

	"time"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/monitor/armmonitor"
)

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/createOrUpdateActionGroup.json
func ExampleActionGroupsClient_CreateOrUpdate() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.CreateOrUpdate(ctx,
		"<resource-group-name>",
		"<action-group-name>",
		armmonitor.ActionGroupResource{
			Location: to.Ptr("<location>"),
			Tags:     map[string]*string{},
			Properties: &armmonitor.ActionGroup{
				ArmRoleReceivers: []*armmonitor.ArmRoleReceiver{
					{
						Name:                 to.Ptr("<name>"),
						RoleID:               to.Ptr("<role-id>"),
						UseCommonAlertSchema: to.Ptr(true),
					}},
				AutomationRunbookReceivers: []*armmonitor.AutomationRunbookReceiver{
					{
						Name:                 to.Ptr("<name>"),
						AutomationAccountID:  to.Ptr("<automation-account-id>"),
						IsGlobalRunbook:      to.Ptr(false),
						RunbookName:          to.Ptr("<runbook-name>"),
						ServiceURI:           to.Ptr("<service-uri>"),
						UseCommonAlertSchema: to.Ptr(true),
						WebhookResourceID:    to.Ptr("<webhook-resource-id>"),
					}},
				AzureAppPushReceivers: []*armmonitor.AzureAppPushReceiver{
					{
						Name:         to.Ptr("<name>"),
						EmailAddress: to.Ptr("<email-address>"),
					}},
				AzureFunctionReceivers: []*armmonitor.AzureFunctionReceiver{
					{
						Name:                  to.Ptr("<name>"),
						FunctionAppResourceID: to.Ptr("<function-app-resource-id>"),
						FunctionName:          to.Ptr("<function-name>"),
						HTTPTriggerURL:        to.Ptr("<httptrigger-url>"),
						UseCommonAlertSchema:  to.Ptr(true),
					}},
				EmailReceivers: []*armmonitor.EmailReceiver{
					{
						Name:                 to.Ptr("<name>"),
						EmailAddress:         to.Ptr("<email-address>"),
						UseCommonAlertSchema: to.Ptr(false),
					},
					{
						Name:                 to.Ptr("<name>"),
						EmailAddress:         to.Ptr("<email-address>"),
						UseCommonAlertSchema: to.Ptr(true),
					}},
				Enabled: to.Ptr(true),
				EventHubReceivers: []*armmonitor.EventHubReceiver{
					{
						Name:              to.Ptr("<name>"),
						EventHubName:      to.Ptr("<event-hub-name>"),
						EventHubNameSpace: to.Ptr("<event-hub-name-space>"),
						SubscriptionID:    to.Ptr("<subscription-id>"),
						TenantID:          to.Ptr("<tenant-id>"),
					}},
				GroupShortName: to.Ptr("<group-short-name>"),
				ItsmReceivers: []*armmonitor.ItsmReceiver{
					{
						Name:                to.Ptr("<name>"),
						ConnectionID:        to.Ptr("<connection-id>"),
						Region:              to.Ptr("<region>"),
						TicketConfiguration: to.Ptr("<ticket-configuration>"),
						WorkspaceID:         to.Ptr("<workspace-id>"),
					}},
				LogicAppReceivers: []*armmonitor.LogicAppReceiver{
					{
						Name:                 to.Ptr("<name>"),
						CallbackURL:          to.Ptr("<callback-url>"),
						ResourceID:           to.Ptr("<resource-id>"),
						UseCommonAlertSchema: to.Ptr(false),
					}},
				SmsReceivers: []*armmonitor.SmsReceiver{
					{
						Name:        to.Ptr("<name>"),
						CountryCode: to.Ptr("<country-code>"),
						PhoneNumber: to.Ptr("<phone-number>"),
					},
					{
						Name:        to.Ptr("<name>"),
						CountryCode: to.Ptr("<country-code>"),
						PhoneNumber: to.Ptr("<phone-number>"),
					}},
				VoiceReceivers: []*armmonitor.VoiceReceiver{
					{
						Name:        to.Ptr("<name>"),
						CountryCode: to.Ptr("<country-code>"),
						PhoneNumber: to.Ptr("<phone-number>"),
					}},
				WebhookReceivers: []*armmonitor.WebhookReceiver{
					{
						Name:                 to.Ptr("<name>"),
						ServiceURI:           to.Ptr("<service-uri>"),
						UseCommonAlertSchema: to.Ptr(true),
					},
					{
						Name:                 to.Ptr("<name>"),
						IdentifierURI:        to.Ptr("<identifier-uri>"),
						ObjectID:             to.Ptr("<object-id>"),
						ServiceURI:           to.Ptr("<service-uri>"),
						TenantID:             to.Ptr("<tenant-id>"),
						UseAADAuth:           to.Ptr(true),
						UseCommonAlertSchema: to.Ptr(true),
					}},
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/getActionGroup.json
func ExampleActionGroupsClient_Get() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Get(ctx,
		"<resource-group-name>",
		"<action-group-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/deleteActionGroup.json
func ExampleActionGroupsClient_Delete() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	_, err = client.Delete(ctx,
		"<resource-group-name>",
		"<action-group-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/patchActionGroup.json
func ExampleActionGroupsClient_Update() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Update(ctx,
		"<resource-group-name>",
		"<action-group-name>",
		armmonitor.ActionGroupPatchBody{
			Properties: &armmonitor.ActionGroupPatch{
				Enabled: to.Ptr(false),
			},
			Tags: map[string]*string{
				"key1": to.Ptr("value1"),
				"key2": to.Ptr("value2"),
			},
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/postTestNotifications.json
func ExampleActionGroupsClient_BeginPostTestNotifications() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	poller, err := client.BeginPostTestNotifications(ctx,
		armmonitor.NotificationRequestBody{
			AlertType: to.Ptr("<alert-type>"),
			AutomationRunbookReceivers: []*armmonitor.AutomationRunbookReceiver{
				{
					Name:                 to.Ptr("<name>"),
					AutomationAccountID:  to.Ptr("<automation-account-id>"),
					IsGlobalRunbook:      to.Ptr(false),
					RunbookName:          to.Ptr("<runbook-name>"),
					ServiceURI:           to.Ptr("<service-uri>"),
					UseCommonAlertSchema: to.Ptr(true),
					WebhookResourceID:    to.Ptr("<webhook-resource-id>"),
				}},
			AzureAppPushReceivers: []*armmonitor.AzureAppPushReceiver{
				{
					Name:         to.Ptr("<name>"),
					EmailAddress: to.Ptr("<email-address>"),
				}},
			AzureFunctionReceivers: []*armmonitor.AzureFunctionReceiver{
				{
					Name:                  to.Ptr("<name>"),
					FunctionAppResourceID: to.Ptr("<function-app-resource-id>"),
					FunctionName:          to.Ptr("<function-name>"),
					HTTPTriggerURL:        to.Ptr("<httptrigger-url>"),
					UseCommonAlertSchema:  to.Ptr(true),
				}},
			EmailReceivers: []*armmonitor.EmailReceiver{
				{
					Name:                 to.Ptr("<name>"),
					EmailAddress:         to.Ptr("<email-address>"),
					UseCommonAlertSchema: to.Ptr(false),
				},
				{
					Name:                 to.Ptr("<name>"),
					EmailAddress:         to.Ptr("<email-address>"),
					UseCommonAlertSchema: to.Ptr(true),
				}},
			EventHubReceivers: []*armmonitor.EventHubReceiver{
				{
					Name:              to.Ptr("<name>"),
					EventHubName:      to.Ptr("<event-hub-name>"),
					EventHubNameSpace: to.Ptr("<event-hub-name-space>"),
					SubscriptionID:    to.Ptr("<subscription-id>"),
					TenantID:          to.Ptr("<tenant-id>"),
				}},
			ItsmReceivers: []*armmonitor.ItsmReceiver{
				{
					Name:                to.Ptr("<name>"),
					ConnectionID:        to.Ptr("<connection-id>"),
					Region:              to.Ptr("<region>"),
					TicketConfiguration: to.Ptr("<ticket-configuration>"),
					WorkspaceID:         to.Ptr("<workspace-id>"),
				}},
			LogicAppReceivers: []*armmonitor.LogicAppReceiver{
				{
					Name:                 to.Ptr("<name>"),
					CallbackURL:          to.Ptr("<callback-url>"),
					ResourceID:           to.Ptr("<resource-id>"),
					UseCommonAlertSchema: to.Ptr(false),
				}},
			SmsReceivers: []*armmonitor.SmsReceiver{
				{
					Name:        to.Ptr("<name>"),
					CountryCode: to.Ptr("<country-code>"),
					PhoneNumber: to.Ptr("<phone-number>"),
				},
				{
					Name:        to.Ptr("<name>"),
					CountryCode: to.Ptr("<country-code>"),
					PhoneNumber: to.Ptr("<phone-number>"),
				}},
			VoiceReceivers: []*armmonitor.VoiceReceiver{
				{
					Name:        to.Ptr("<name>"),
					CountryCode: to.Ptr("<country-code>"),
					PhoneNumber: to.Ptr("<phone-number>"),
				}},
			WebhookReceivers: []*armmonitor.WebhookReceiver{
				{
					Name:                 to.Ptr("<name>"),
					ServiceURI:           to.Ptr("<service-uri>"),
					UseCommonAlertSchema: to.Ptr(true),
				},
				{
					Name:                 to.Ptr("<name>"),
					IdentifierURI:        to.Ptr("<identifier-uri>"),
					ObjectID:             to.Ptr("<object-id>"),
					ServiceURI:           to.Ptr("<service-uri>"),
					TenantID:             to.Ptr("<tenant-id>"),
					UseAADAuth:           to.Ptr(true),
					UseCommonAlertSchema: to.Ptr(true),
				}},
		},
		&armmonitor.ActionGroupsClientBeginPostTestNotificationsOptions{ResumeToken: ""})
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	_, err = poller.PollUntilDone(ctx, 30*time.Second)
	if err != nil {
		log.Fatalf("failed to pull the result: %v", err)
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/getTestNotifications.json
func ExampleActionGroupsClient_GetTestNotifications() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.GetTestNotifications(ctx,
		"<notification-id>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/listActionGroups.json
func ExampleActionGroupsClient_NewListByResourceGroupPager() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	pager := client.NewListByResourceGroupPager("<resource-group-name>",
		nil)
	for pager.More() {
		nextResult, err := pager.NextPage(ctx)
		if err != nil {
			log.Fatalf("failed to advance page: %v", err)
			return
		}
		for _, v := range nextResult.Value {
			// TODO: use page item
			_ = v
		}
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/monitor/resource-manager/Microsoft.Insights/stable/2021-09-01/examples/enableReceiver.json
func ExampleActionGroupsClient_EnableReceiver() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armmonitor.NewActionGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	_, err = client.EnableReceiver(ctx,
		"<resource-group-name>",
		"<action-group-name>",
		armmonitor.EnableRequest{
			ReceiverName: to.Ptr("<receiver-name>"),
		},
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
}
