//go:build go1.18
// +build go1.18

// Copyright (c) Microsoft Corporation. All rights reserved.
// Licensed under the MIT License. See License.txt in the project root for license information.
// Code generated by Microsoft (R) AutoRest Code Generator.
// Changes may cause incorrect behavior and will be lost if the code is regenerated.

package armnetapp_test

import (
	"context"
	"log"

	"time"

	"github.com/Azure/azure-sdk-for-go/sdk/azcore/to"
	"github.com/Azure/azure-sdk-for-go/sdk/azidentity"
	"github.com/Azure/azure-sdk-for-go/sdk/resourcemanager/netapp/armnetapp"
)

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/netapp/resource-manager/Microsoft.NetApp/stable/2021-10-01/examples/VolumeGroups_List.json
func ExampleVolumeGroupsClient_NewListByNetAppAccountPager() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armnetapp.NewVolumeGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	pager := client.NewListByNetAppAccountPager("<resource-group-name>",
		"<account-name>",
		nil)
	for pager.More() {
		nextResult, err := pager.NextPage(ctx)
		if err != nil {
			log.Fatalf("failed to advance page: %v", err)
			return
		}
		for _, v := range nextResult.Value {
			// TODO: use page item
			_ = v
		}
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/netapp/resource-manager/Microsoft.NetApp/stable/2021-10-01/examples/VolumeGroups_Get.json
func ExampleVolumeGroupsClient_Get() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armnetapp.NewVolumeGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	res, err := client.Get(ctx,
		"<resource-group-name>",
		"<account-name>",
		"<volume-group-name>",
		nil)
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	// TODO: use response item
	_ = res
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/netapp/resource-manager/Microsoft.NetApp/stable/2021-10-01/examples/VolumeGroups_Create.json
func ExampleVolumeGroupsClient_BeginCreate() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armnetapp.NewVolumeGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	poller, err := client.BeginCreate(ctx,
		"<resource-group-name>",
		"<account-name>",
		"<volume-group-name>",
		armnetapp.VolumeGroupDetails{
			Location: to.Ptr("<location>"),
			Properties: &armnetapp.VolumeGroupProperties{
				GroupMetaData: &armnetapp.VolumeGroupMetaData{
					ApplicationIdentifier: to.Ptr("<application-identifier>"),
					ApplicationType:       to.Ptr(armnetapp.ApplicationTypeSAPHANA),
					DeploymentSpecID:      to.Ptr("<deployment-spec-id>"),
					GroupDescription:      to.Ptr("<group-description>"),
				},
				Volumes: []*armnetapp.VolumeGroupVolumeProperties{
					{
						Name: to.Ptr("<name>"),
						Properties: &armnetapp.VolumeProperties{
							CapacityPoolResourceID:  to.Ptr("<capacity-pool-resource-id>"),
							CreationToken:           to.Ptr("<creation-token>"),
							ProximityPlacementGroup: to.Ptr("<proximity-placement-group>"),
							ServiceLevel:            to.Ptr(armnetapp.ServiceLevelPremium),
							SubnetID:                to.Ptr("<subnet-id>"),
							ThroughputMibps:         to.Ptr[float32](10),
							UsageThreshold:          to.Ptr[int64](107374182400),
							VolumeSpecName:          to.Ptr("<volume-spec-name>"),
						},
					},
					{
						Name: to.Ptr("<name>"),
						Properties: &armnetapp.VolumeProperties{
							CapacityPoolResourceID:  to.Ptr("<capacity-pool-resource-id>"),
							CreationToken:           to.Ptr("<creation-token>"),
							ProximityPlacementGroup: to.Ptr("<proximity-placement-group>"),
							ServiceLevel:            to.Ptr(armnetapp.ServiceLevelPremium),
							SubnetID:                to.Ptr("<subnet-id>"),
							ThroughputMibps:         to.Ptr[float32](10),
							UsageThreshold:          to.Ptr[int64](107374182400),
							VolumeSpecName:          to.Ptr("<volume-spec-name>"),
						},
					},
					{
						Name: to.Ptr("<name>"),
						Properties: &armnetapp.VolumeProperties{
							CapacityPoolResourceID:  to.Ptr("<capacity-pool-resource-id>"),
							CreationToken:           to.Ptr("<creation-token>"),
							ProximityPlacementGroup: to.Ptr("<proximity-placement-group>"),
							ServiceLevel:            to.Ptr(armnetapp.ServiceLevelPremium),
							SubnetID:                to.Ptr("<subnet-id>"),
							ThroughputMibps:         to.Ptr[float32](10),
							UsageThreshold:          to.Ptr[int64](107374182400),
							VolumeSpecName:          to.Ptr("<volume-spec-name>"),
						},
					}},
			},
		},
		&armnetapp.VolumeGroupsClientBeginCreateOptions{ResumeToken: ""})
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	_, err = poller.PollUntilDone(ctx, 30*time.Second)
	if err != nil {
		log.Fatalf("failed to pull the result: %v", err)
	}
}

// Generated from example definition: https://github.com/Azure/azure-rest-api-specs/tree/main/specification/netapp/resource-manager/Microsoft.NetApp/stable/2021-10-01/examples/VolumeGroups_Delete.json
func ExampleVolumeGroupsClient_BeginDelete() {
	cred, err := azidentity.NewDefaultAzureCredential(nil)
	if err != nil {
		log.Fatalf("failed to obtain a credential: %v", err)
	}
	ctx := context.Background()
	client, err := armnetapp.NewVolumeGroupsClient("<subscription-id>", cred, nil)
	if err != nil {
		log.Fatalf("failed to create client: %v", err)
	}
	poller, err := client.BeginDelete(ctx,
		"<resource-group-name>",
		"<account-name>",
		"<volume-group-name>",
		&armnetapp.VolumeGroupsClientBeginDeleteOptions{ResumeToken: ""})
	if err != nil {
		log.Fatalf("failed to finish the request: %v", err)
	}
	_, err = poller.PollUntilDone(ctx, 30*time.Second)
	if err != nil {
		log.Fatalf("failed to pull the result: %v", err)
	}
}
